<p align="center">
<img src="https://pc.woozooo.com/img/logo2.gif" width="200">
</p>

<h1 align="center">- 蓝奏云API -</h1>

# 简介

- 本库封装了蓝奏网盘的基础功能: 登录、注销、获取文件(夹)列表、下载文件、上传文件、删除文件(夹)、
移动文件、清空回收站、恢复文件(夹)、创建文件夹、设置文件(夹)访问密码、设置文件(夹)描述

# 免责声明

- 本项目仅供个人学习使用，严禁用于商业用途
- **本项目没有任何担保**，如果您使用这些代码，您必需承担其带来的风险

# API 文档
- 使用 `pip install olz` 即可安装
- API 文档请查看 [wiki](https://github.com/HG-ha/olz/wiki) 页面

# 更新日志

## `v0.0.1`

- 修复账号密码登录，修复登录态失败，修复文件及文件夹解析，修复很多小BUG